@@ -2,10 +2,10 @@
 
 # last modified 2 October 2009 by J. Fox
 # 2017-11-30: substitute carPalette() for palette(). J. Fox
-
+# 2019-11-14: change class(x) == "y" to inherits(x, "y")
  
 regLine <- function(mod, col=carPalette()[2], lwd=2, lty=1, ...){
-	if(!is.null(class(mod$na.action)) && class(mod$na.action) == "exclude") 
+	if(!is.null(class(mod$na.action)) && inherits(mod$na.action, "exclude"))
 		class(mod$na.action) <-"omit"
 	coef <- coefficients(mod)
 	if (length(coef) != 2) stop("requires simple linear regression")
